"""Exception classes."""
import urllib3


class MyHomeException(Exception):
    """Base exception class."""


class LoginFailure(MyHomeException):
    """Login failure."""

    def __init__(self, resp: urllib3.response.HTTPResponse, message: str):
        """Construct exception."""
        self.resp = resp
        super().__init__(message)


class RemoteAccessDenied(LoginFailure):
    """Remote access is not permitted for given user."""

    def __init__(self, resp: urllib3.response.Response):
        """Construct exception."""
        super().__init__(resp, "Remote access denied for user")


class UnknownLoginFailure(LoginFailure):
    """Unknown login failure."""

    def __init__(self, resp: urllib3.response.Response):
        """Construct exception."""
        super().__init__(resp, "An unknown issue has occurred during login")


class LoginDenied(LoginFailure):
    """Username and/or password incorrect."""

    def __init__(self, resp: urllib3.response.Response):
        """Construct exception."""
        super().__init__(resp, "Username and/or password incorrect")



"""
    MyHomeSERVER1 API

    API provided by the Bticino MyHomeSERVER1 system and used by the MyHomeUp mobile application  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import myhome._gen
from myhome._gen.model.object_value_thermostat import ObjectValueThermostat


class TestObjectValueThermostat(unittest.TestCase):
    """ObjectValueThermostat unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testObjectValueThermostat(self):
        """Test ObjectValueThermostat"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ObjectValueThermostat()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""Base implementation and helpers."""
import json
import typing

from .._gen.api.default_api import DefaultApi
from .._gen.model.object_info import ObjectInfo
from .._gen.model.object_value import ObjectValue
from .._gen.model.object_value_dimmer import ObjectValueDimmer
from .._gen.model.object_value_light import ObjectValueLight
from .._gen.model.object_value_shutter import ObjectValueShutter
from .._gen.model.object_value_thermostat import ObjectValueThermostat
from .._gen.model.room import Room
from .._gen.model.set_object_value_request import SetObjectValueRequest
from .._gen.model.specific_object_request import SpecificObjectRequest
from .._gen.model.zone import Zone


class BaseObject:
    """Base object class."""

    def __init__(
        self,
        api: DefaultApi,
        object_info: ObjectInfo,
        zone: typing.Optional[Zone] = None,
        room: typing.Optional[Room] = None,
    ):
        """Construct base object."""
        self._api = api
        self._object_info = object_info
        self._decoded_property: typing.Optional[typing.Iterable[str]] = None
        self._zone = zone
        self._room = room

    def get_value(self) -> ObjectValue:
        """Retrieve object value."""
        return self._api.get_object_value(SpecificObjectRequest(id=float(self.id)))

    def set_value(
        self,
        value: typing.Union[
            ObjectValueDimmer,
            ObjectValueLight,
            ObjectValueShutter,
            ObjectValueThermostat,
        ],
    ):
        """Set object value."""
        return self._api.set_object_value(
            SetObjectValueRequest(id=float(self.id), value=value)
        )

    @property
    def id(self) -> int:
        """Return object ID."""
        return int(self._object_info.id)

    @property
    def room_id(self) -> int:
        """Return object room ID."""
        return int(self._object_info.id_room)

    @property
    def room(self) -> typing.Optional[Room]:
        """Return room object if known."""
        return self._room

    @property
    def zone_id(self) -> int:
        """Return object zone ID."""
        return int(self._object_info.id_zone)

    @property
    def zone(self) -> typing.Optional[Zone]:
        """Return zone object if known."""
        return self._zone

    @property
    def type(self) -> str:
        """Return object type name."""
        return self._object_info.type

    @property
    def name(self) -> str:
        """Return object name."""
        return self._object_info.name

    @property
    def property(self) -> typing.Iterable[str]:
        """Return object property."""
        if self._decoded_property is None:
            self._decoded_property = json.loads(self._object_info._property)
        return self._decoded_property

    def __repr__(self) -> str:
        """Return the basic object properties."""
        return f"<Object: id={self.id},type={self.type},name={self.name}>"



"""Light support."""
import typing

from .._gen.api.default_api import DefaultApi
from .._gen.model.object_info import ObjectInfo
from .._gen.model.object_value_dimmer import ObjectValueDimmer
from .._gen.model.object_value_light import ObjectValueLight
from .._gen.model.room import Room
from .._gen.model.zone import Zone
from .base import BaseObject


class Light(BaseObject):
    """Represent a light."""

    def __init__(
        self,
        api: DefaultApi,
        object_info: ObjectInfo,
        zone: typing.Optional[Zone] = None,
        room: typing.Optional[Room] = None,
    ):
        """Construct light."""
        super().__init__(api, object_info, zone=zone, room=room)

    def switch_on(self):
        """Switch light on."""
        return self.set_value(ObjectValueLight(power=True))

    def switch_off(self):
        """Switch light off."""
        return self.set_value(ObjectValueLight(power=False))

    @property
    def is_on(self):
        """Return True if light is switched on."""
        return self.get_value().power


class Dimmer(Light):
    """Represent a dimmer."""

    def dim(self, percentage: int):
        """Dim to provided percentage."""
        return self.set_value(ObjectValueDimmer(dimmer=percentage))

    def is_on(self):
        """Return True if dimmer is switched on."""
        return self.dimmer_level > 0

    @property
    def dimmer_level(self):
        """Return dimmer level."""
        return self.get_value().dimmer



"""myhome provides a client library for interacting with Bticino MYHOMESERVER1 via its built-in RESTful API.

This API is used by the MyHomeUp mobile application as well and allows full
control of the underlying home automation bus.

The intention here is to provide an implementation of a client library
based on the reverse-engineering network interactions, which are documented
at https://github.com/speijnik/myhome/tree/main/doc/
"""

__version__ = "0.1.0"



# flake8: noqa

"""
    MyHomeSERVER1 API

    API provided by the Bticino MyHomeSERVER1 system and used by the MyHomeUp mobile application  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from myhome._gen.api_client import ApiClient

# import Configuration
from myhome._gen.configuration import Configuration

# import exceptions
from myhome._gen.exceptions import (
    ApiAttributeError,
    ApiException,
    ApiKeyError,
    ApiTypeError,
    ApiValueError,
    OpenApiException,
)



"""Object-specific logic."""
import typing

from .._gen.api.default_api import DefaultApi  # type: ignore
from .._gen.model.object_info import ObjectInfo  # type: ignore
from .._gen.model.room import Room  # type: ignore
from .._gen.model.zone import Zone  # type: ignore
from ..exception import MyHomeException
from .base import BaseObject
from .light import Dimmer, Light
from .shutter import Shutter
from .thermostat import Thermostat

OBJ_TYPE_CLASS_MAP = {
    "light": Light,
    "shutter": Shutter,
    "thermostat": Thermostat,
}

OBJ_TYPE_SUBCLASS_MAP = {
    "light": {
        "dimmer": Dimmer,
    }
}


def object_factory(
    api: DefaultApi,
    raw_obj: ObjectInfo,
    zone: typing.Optional[Zone],
    room: typing.Optional[Room],
) -> BaseObject:
    """Return type-specific instance from raw object."""
    obj_class: typing.Optional[typing.Type[BaseObject]] = None
    subclass_map = OBJ_TYPE_SUBCLASS_MAP.get(raw_obj.type, None)
    if subclass_map:
        base_obj = BaseObject(api, raw_obj)
        for prop in base_obj.property:
            obj_class = subclass_map.get(prop, None)
            if obj_class:
                break

    if not obj_class:
        obj_class = OBJ_TYPE_CLASS_MAP.get(raw_obj.type, None)

    if not obj_class:
        obj_class = BaseObject

    return obj_class(api, raw_obj, zone=zone, room=room)


class InvalidMatcherFunc(MyHomeException):
    """Invalid matcher provided."""

    def __init__(self, match_name: str):
        """Construct exception."""
        super().__init__(f"Invalid matcher name: {match_name}")


class FilterMatcher:
    """Filter matcher."""

    def __init__(self, filters: typing.Dict[str, typing.Any]):
        """Construct matcher."""
        self._filters = filters

    @staticmethod
    def match_eq(a, b):
        """Match equality."""
        return a == b

    @staticmethod
    def match_startswith(a, b):
        """Match string-starts-with."""
        if not isinstance(a, str) or not isinstance(b, str):
            return False

        return a.startswith(b)

    @staticmethod
    def match_endswith(a, b):
        """Match string-ends-with."""
        if not isinstance(a, str) or not isinstance(b, str):
            return False

        return a.endswith(b)

    @staticmethod
    def match_contains(a, b):
        """Match contains."""
        if not a or not b:
            return False

        return b in a

    def matches(self, obj: object):
        """Return true if object matches filters."""
        for attr, value in self._filters.items():
            attr_name, *rest = attr.split("__", 1)
            match_name = "__".join(rest) or "eq"

            match_fn = getattr(self, "match_" + match_name, None)
            if not callable(match_fn):
                raise InvalidMatcherFunc(match_name)

            if not match_fn(getattr(obj, attr_name, None), value):
                return False
        return True


class ObjectNotFound(MyHomeException):
    """Object matching filters not found."""

    def __init__(self, filters: typing.Dict[str, typing.Any]):
        """Construct exception."""
        filter_defs = [f"{key}={value}" for key, value in filters.items()]
        super().__init__(
            "No object found matching filter {}".format(",".join(sorted(filter_defs)))
        )


class MultipleObjectsFound(MyHomeException):
    """Multiple objects matching filters found."""

    def __init__(self, filters: typing.Dict[str, typing.Any]):
        """Construct exception."""
        filter_defs = [f"{key}={value}" for key, value in filters.items()]
        super().__init__(
            "Multiple objects found matching filter {}".format(
                ",".join(sorted(filter_defs))
            )
        )


class ObjectList(list):
    """Represent a list of objects."""

    def __init__(
        self,
        api: DefaultApi,
        objs: typing.Iterable[typing.Union[ObjectInfo, BaseObject]],
        zones: typing.List[Zone],
        rooms: typing.List[Room],
    ):
        """Construct object list."""
        self._api = api
        self._zones = zones
        self._rooms = rooms

        obj_list = []
        zone_map = {}
        room_map = {}

        for z in zones:
            zone_map.update(
                {
                    z.id: z,
                }
            )

        for r in rooms:
            room_map.update(
                {
                    r.id: r,
                }
            )

        for obj in objs:
            if not isinstance(obj, BaseObject):
                room = room_map.get(obj.id_room, None)
                zone = zone_map.get(obj.id_zone, None)
                obj = object_factory(api, obj, zone, room)
            obj_list.append(obj)
        super().__init__(obj_list)

    def all(self) -> typing.List[BaseObject]:
        """Return all objects."""
        return ObjectList(self._api, self[:])

    def filter(self, **filters) -> typing.List[BaseObject]:
        """Return all objects matching filters."""
        filtered_objs = []
        matcher = FilterMatcher(filters)

        for obj in self:
            if matcher.matches(obj):
                filtered_objs.append(obj)

        return ObjectList(
            self._api, filtered_objs, zones=self._zones, rooms=self._rooms
        )

    def get(self, **filters) -> BaseObject:
        """Return single object matching filters."""
        filtered = self.filter(**filters)

        if len(list(filtered)) == 0:
            raise ObjectNotFound(filters)
        elif len(list(filtered)) > 1:
            raise MultipleObjectsFound(filters)

        return filtered[0]



"""Shutter support."""
import typing

from .._gen.api.default_api import DefaultApi
from .._gen.model.object_info import ObjectInfo
from .._gen.model.object_value_shutter import ObjectValueShutter
from .._gen.model.room import Room
from .._gen.model.zone import Zone
from .base import BaseObject


class Shutter(BaseObject):
    """Represent a shutter."""

    def __init__(
        self,
        api: DefaultApi,
        object_info: ObjectInfo,
        zone: typing.Optional[Zone] = None,
        room: typing.Optional[Room] = None,
    ):
        """Construct shutter."""
        super().__init__(api, object_info, zone=zone, room=room)

    def move_up(self):
        """Shortcut for moving shutter up."""
        return self.move_shutter("UP")

    def move_stop(self):
        """Shortcut for stopping shutter movement."""
        return self.move_shutter("STOP")

    def move_down(self):
        """Shortcut for moving shutter down."""
        return self.move_shutter("DOWN")

    def move_shutter(self, direction: str):
        """Move shutter."""
        return self.set_value(ObjectValueShutter(move=direction))

    def get_shutter_move(self):
        """Return shutter move value."""
        return self.get_value().move



"""Thermostat support."""
import typing

from .._gen.api.default_api import DefaultApi
from .._gen.model.object_info import ObjectInfo
from .._gen.model.object_value_thermostat import ObjectValueThermostat
from .._gen.model.room import Room
from .._gen.model.zone import Zone
from .base import BaseObject


class Thermostat(BaseObject):
    """Represent a thermostat."""

    def __init__(
        self,
        api: DefaultApi,
        object_info: ObjectInfo,
        zone: typing.Optional[Zone] = None,
        room: typing.Optional[Room] = None,
    ):
        """Create thermostat object."""
        super().__init__(api, object_info, zone=zone, room=room)

    def set_temperature(self, temperature: float):
        """Set thermostat temperature."""
        return self.set_value(ObjectValueThermostat(setpoint=temperature))

    def get_temperature(self):
        """Retrieve thermostat temperature."""
        value = self.get_value()
        return value.setpoint



"""
    MyHomeSERVER1 API

    API provided by the Bticino MyHomeSERVER1 system and used by the MyHomeUp mobile application  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from myhome._gen.api_client import ApiClient, Endpoint as _Endpoint
from myhome._gen.model.action_list import ActionList
from myhome._gen.model.get_actual_user_response import GetActualUserResponse
from myhome._gen.model.get_role_user_response import GetRoleUserResponse
from myhome._gen.model.init_check_response import InitCheckResponse
from myhome._gen.model.login_request import LoginRequest
from myhome._gen.model.login_response import LoginResponse
from myhome._gen.model.object_list import ObjectList
from myhome._gen.model.object_value import ObjectValue
from myhome._gen.model.room_list import RoomList
from myhome._gen.model.serial_server import SerialServer
from myhome._gen.model.set_object_value_request import SetObjectValueRequest
from myhome._gen.model.set_object_value_response import SetObjectValueResponse
from myhome._gen.model.specific_object_request import SpecificObjectRequest
from myhome._gen.model.system_info import SystemInfo
from myhome._gen.model.zone_list import ZoneList
from myhome._gen.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types,
)


class DefaultApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_actual_user(
            self,
            body,
            **kwargs
        ):
            """Retrieves current user's ID  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_actual_user(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetActualUserResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_actual_user = _Endpoint(
            settings={
                'response_type': (GetActualUserResponse,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/users/getActualUser',
                'operation_id': 'get_actual_user',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_actual_user
        )

        def __get_object_list(
            self,
            body,
            **kwargs
        ):
            """Retrieves list of objects (devices)  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_object_list(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjectList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_object_list = _Endpoint(
            settings={
                'response_type': (ObjectList,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/objects/list',
                'operation_id': 'get_object_list',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_object_list
        )

        def __get_object_value(
            self,
            specific_object_request,
            **kwargs
        ):
            """Retrieves current object value  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_object_value(specific_object_request, async_req=True)
            >>> result = thread.get()

            Args:
                specific_object_request (SpecificObjectRequest):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjectValue
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['specific_object_request'] = \
                specific_object_request
            return self.call_with_http_info(**kwargs)

        self.get_object_value = _Endpoint(
            settings={
                'response_type': (ObjectValue,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/objects/getValue',
                'operation_id': 'get_object_value',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'specific_object_request',
                ],
                'required': [
                    'specific_object_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'specific_object_request':
                        (SpecificObjectRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'specific_object_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_object_value
        )

        def __get_role_user(
            self,
            body,
            **kwargs
        ):
            """Retrieves user's role  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_role_user(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                GetRoleUserResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_role_user = _Endpoint(
            settings={
                'response_type': (GetRoleUserResponse,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/users/getRoleUser',
                'operation_id': 'get_role_user',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_role_user
        )

        def __get_room_list(
            self,
            body,
            **kwargs
        ):
            """Retrieves list of rooms  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_room_list(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RoomList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_room_list = _Endpoint(
            settings={
                'response_type': (RoomList,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/rooms/list',
                'operation_id': 'get_room_list',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_room_list
        )

        def __get_scene_list(
            self,
            body,
            **kwargs
        ):
            """Retrieves list of scenes (actions)  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_scene_list(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ActionList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_scene_list = _Endpoint(
            settings={
                'response_type': (ActionList,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/actions/list',
                'operation_id': 'get_scene_list',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_scene_list
        )

        def __get_serial_server(
            self,
            body,
            **kwargs
        ):
            """Retrieves system serial number  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_serial_server(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SerialServer
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_serial_server = _Endpoint(
            settings={
                'response_type': (SerialServer,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/system/getSerialServer',
                'operation_id': 'get_serial_server',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_serial_server
        )

        def __get_system_info(
            self,
            body,
            **kwargs
        ):
            """Retrieves basic system information  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_system_info(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SystemInfo
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_system_info = _Endpoint(
            settings={
                'response_type': (SystemInfo,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/system/getSystemInfo',
                'operation_id': 'get_system_info',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_system_info
        )

        def __get_zone_list(
            self,
            body,
            **kwargs
        ):
            """Retrieves list of zones  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_zone_list(body, async_req=True)
            >>> result = thread.get()

            Args:
                body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ZoneList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.get_zone_list = _Endpoint(
            settings={
                'response_type': (ZoneList,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/zone/list',
                'operation_id': 'get_zone_list',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_zone_list
        )

        def __init_check(
            self,
            **kwargs
        ):
            """Checks if system has fully started  # noqa: E501

            This operation is invoked to check if system startup has fully completed. The meaning of this method needs some further research.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.init_check(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                InitCheckResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.init_check = _Endpoint(
            settings={
                'response_type': (InitCheckResponse,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/plugins/bticino/initCheck',
                'operation_id': 'init_check',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__init_check
        )

        def __login(
            self,
            x_real_ip,
            login_request,
            **kwargs
        ):
            """Authenticates with the MyHomeSERVER1 system  # noqa: E501

            A successful call causes the session to become authenticated  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.login(x_real_ip, login_request, async_req=True)
            >>> result = thread.get()

            Args:
                x_real_ip (str):
                login_request (LoginRequest):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                LoginResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_real_ip'] = \
                x_real_ip
            kwargs['login_request'] = \
                login_request
            return self.call_with_http_info(**kwargs)

        self.login = _Endpoint(
            settings={
                'response_type': (LoginResponse,),
                'auth': [],
                'endpoint_path': '/rest/login/access',
                'operation_id': 'login',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_real_ip',
                    'login_request',
                ],
                'required': [
                    'x_real_ip',
                    'login_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_real_ip':
                        (str,),
                    'login_request':
                        (LoginRequest,),
                },
                'attribute_map': {
                    'x_real_ip': 'X-Real-IP',
                },
                'location_map': {
                    'x_real_ip': 'header',
                    'login_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__login
        )

        def __set_object_value(
            self,
            set_object_value_request,
            **kwargs
        ):
            """Retrieves current object value  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.set_object_value(set_object_value_request, async_req=True)
            >>> result = thread.get()

            Args:
                set_object_value_request (SetObjectValueRequest):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SetObjectValueResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['set_object_value_request'] = \
                set_object_value_request
            return self.call_with_http_info(**kwargs)

        self.set_object_value = _Endpoint(
            settings={
                'response_type': (SetObjectValueResponse,),
                'auth': [
                    'cookieAuth'
                ],
                'endpoint_path': '/rest/objects/setValue',
                'operation_id': 'set_object_value',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'set_object_value_request',
                ],
                'required': [
                    'set_object_value_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'set_object_value_request':
                        (SetObjectValueRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'set_object_value_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__set_object_value
        )



"""API client implementation."""
from http.cookies import SimpleCookie
import io
import typing

from . import __version__
from ._gen import ApiClient, Configuration  # type: ignore
from ._gen.api.default_api import DefaultApi  # type: ignore
from ._gen.model.login_request import LoginRequest  # type: ignore
from ._gen.model.room import Room  # type: ignore
from ._gen.model.zone import Zone  # type: ignore
from .exception import LoginDenied, RemoteAccessDenied, UnknownLoginFailure
from .object import ObjectList

LOGIN_ERROR_EXCEPTION_CLASSES: typing.Dict[str, typing.Any] = {
    "notRemote": RemoteAccessDenied,
    "error": LoginDenied,
}


class CustomAPIClient(ApiClient):
    """Customized ApiClient variant that handles the session cookie."""

    def call_api(
        self,
        resource_path: str,
        method: str,
        path_params: typing.Optional[typing.Dict[str, typing.Any]] = None,
        query_params: typing.Optional[
            typing.List[typing.Tuple[str, typing.Any]]
        ] = None,
        header_params: typing.Optional[typing.Dict[str, typing.Any]] = None,
        body: typing.Optional[typing.Any] = None,
        post_params: typing.Optional[typing.List[typing.Tuple[str, typing.Any]]] = None,
        files: typing.Optional[typing.Dict[str, typing.List[io.IOBase]]] = None,
        response_type: typing.Optional[typing.Tuple[typing.Any]] = None,
        auth_settings: typing.Optional[typing.List[str]] = None,
        async_req: typing.Optional[bool] = None,
        _return_http_data_only: typing.Optional[bool] = None,
        collection_formats: typing.Optional[typing.Dict[str, str]] = None,
        _preload_content: bool = True,
        _request_timeout: typing.Optional[
            typing.Union[int, float, typing.Tuple]
        ] = None,
        _host: typing.Optional[str] = None,
        _check_type: typing.Optional[bool] = None,
    ):
        """Eended version of call_api."""
        return_data, response_status, response_headers = super().call_api(
            resource_path,
            method,
            path_params=path_params,
            query_params=query_params,
            header_params=header_params,
            body=body,
            post_params=post_params,
            files=files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=async_req,
            _return_http_data_only=False,
            collection_formats=collection_formats,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _host=_host,
            _check_type=_check_type,
        )

        if "Set-Cookie" in response_headers:
            cookie = SimpleCookie(response_headers["Set-Cookie"])
            if "JSESSIONID" in cookie:
                self.configuration.api_key = {
                    "cookieAuth": "JSESSIONID=" + cookie["JSESSIONID"].value,
                }

        if _return_http_data_only:
            return return_data
        return return_data, response_status, response_headers


class Client:
    """Client object."""

    def __init__(self, ip_address: str, port: int = 3443):
        """Construct client."""
        self._ip_address = ip_address
        api_config = Configuration(
            host=f"https://{ip_address}:{port}",
        )
        api_config.debug = True
        api_config.verify_ssl = False

        self._client = CustomAPIClient(configuration=api_config)

        self._client.user_agent = f"python-myhome/{__version__}"
        self._api = DefaultApi(api_client=self._client)

    def login(self, username: str, password: str) -> None:
        """Authenticate with server."""
        resp = self._api.login(
            self._ip_address, LoginRequest(user=username, password=password)
        )

        if resp.access != "success":
            login_error_exception_class = LOGIN_ERROR_EXCEPTION_CLASSES.get(
                resp.access, UnknownLoginFailure
            )
            raise login_error_exception_class(resp)
        return resp

    def get_object_list(self) -> ObjectList:
        """Return list of objects."""
        raw_objects = self._api.get_object_list({}).value
        zones = self.get_zone_list()
        rooms = self.get_room_list()
        return ObjectList(self._api, raw_objects, zones, rooms)

    def get_room_list(self) -> typing.List[Room]:
        """Return list of rooms."""
        return self._api.get_room_list({}).value

    def get_zone_list(self) -> typing.List[Zone]:
        """Return list of zones."""
        return self._api.get_zone_list({}).value



"""
    MyHomeSERVER1 API

    API provided by the Bticino MyHomeSERVER1 system and used by the MyHomeUp mobile application  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import myhome._gen
from myhome._gen.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_actual_user(self):
        """Test case for get_actual_user

        Retrieves current user's ID  # noqa: E501
        """
        pass

    def test_get_object_list(self):
        """Test case for get_object_list

        Retrieves list of objects (devices)  # noqa: E501
        """
        pass

    def test_get_object_value(self):
        """Test case for get_object_value

        Retrieves current object value  # noqa: E501
        """
        pass

    def test_get_role_user(self):
        """Test case for get_role_user

        Retrieves user's role  # noqa: E501
        """
        pass

    def test_get_room_list(self):
        """Test case for get_room_list

        Retrieves list of rooms  # noqa: E501
        """
        pass

    def test_get_scene_list(self):
        """Test case for get_scene_list

        Retrieves list of scenes (actions)  # noqa: E501
        """
        pass

    def test_get_serial_server(self):
        """Test case for get_serial_server

        Retrieves system serial number  # noqa: E501
        """
        pass

    def test_get_system_info(self):
        """Test case for get_system_info

        Retrieves basic system information  # noqa: E501
        """
        pass

    def test_get_zone_list(self):
        """Test case for get_zone_list

        Retrieves list of zones  # noqa: E501
        """
        pass

    def test_init_check(self):
        """Test case for init_check

        Checks if system has fully started  # noqa: E501
        """
        pass

    def test_login(self):
        """Test case for login

        Authenticates with the MyHomeSERVER1 system  # noqa: E501
        """
        pass

    def test_set_object_value(self):
        """Test case for set_object_value

        Retrieves current object value  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['myhome',
 'myhome._gen',
 'myhome._gen.api',
 'myhome._gen.apis',
 'myhome._gen.model',
 'myhome._gen.models',
 'myhome._gen.test',
 'myhome.object']

package_data = \
{'': ['*']}

install_requires = \
['pytest-cov>=2.12.1,<3.0.0', 'urllib3>=1.26.2']

setup_kwargs = {
    'name': 'myhome',
    'version': '0.2.0',
    'description': 'Python client library for interacting with Bticino MMYHOMESERVER1',
    'long_description': '# myhome\n\n*myhome* is a Python package providing an API client for the Legrand/Bticino MyHomeSERVER1 API.\n\nThis API is usually used by the *MyHome_UP* mobile application and has been partially\nreverse-engineered from intercepting the traffic between the application and the server\nrunning on the local network. You can find information on the [analysis setup](doc/analysis_setup.md)\nand the [API](doc/api.md) itself in the *doc* directory of this repository.\n\nPlease be aware that this is a very early version of the library and things may change at any\npoint in time.\nThe long-term goal is to implement a library with a stable interface which can then be\nused in home automation systems and frameworks, like *Home Assistant*.\n\n## OpenAPI spec\n\nThis repository contains an [OpenAPI spec](contrib/openapi.yml) which partially describes\nthe API exposed by MyHomeSERVER1.\n\n## Status\n\n- [x] Basic light control\n- [x] Basic dimmer control\n- [x] Basic shutter control\n- [x] Basic thermostat control\n- [x] Basic room support\n- [x] Basic zone support\n- [x] CI pipeline\n- [ ] Unit tests\n- [ ] Library documentation\n',
    'author': 'Stephan Peijnik-Steinwender',
    'author_email': 'speijnik@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/speijnik/myhome',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from myhome._gen.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from myhome._gen.model.access_status import AccessStatus
from myhome._gen.model.action import Action
from myhome._gen.model.action_list import ActionList
from myhome._gen.model.event import Event
from myhome._gen.model.get_actual_user_response import GetActualUserResponse
from myhome._gen.model.get_role_user_response import GetRoleUserResponse
from myhome._gen.model.init_check_response import InitCheckResponse
from myhome._gen.model.login_request import LoginRequest
from myhome._gen.model.login_response import LoginResponse
from myhome._gen.model.object_info import ObjectInfo
from myhome._gen.model.object_list import ObjectList
from myhome._gen.model.object_value import ObjectValue
from myhome._gen.model.object_value_dimmer import ObjectValueDimmer
from myhome._gen.model.object_value_light import ObjectValueLight
from myhome._gen.model.object_value_shutter import ObjectValueShutter
from myhome._gen.model.object_value_thermostat import ObjectValueThermostat
from myhome._gen.model.room import Room
from myhome._gen.model.room_list import RoomList
from myhome._gen.model.serial_server import SerialServer
from myhome._gen.model.set_object_value_request import SetObjectValueRequest
from myhome._gen.model.set_object_value_response import SetObjectValueResponse
from myhome._gen.model.specific_object_request import SpecificObjectRequest
from myhome._gen.model.system_info import SystemInfo
from myhome._gen.model.zone import Zone
from myhome._gen.model.zone_list import ZoneList
